@@ -33,6 +33,7 @@
  */
 
 #include "spice_plugin.h"
+#include "spice_file.h"
 
 #define XSPICE_DEFAULT_PORT 5900
 
@@ -129,6 +130,7 @@ static void remmina_plugin_spice_init(RemminaProtocolWidget *gp)
 		"enable-audio", remmina_plugin_service->file_get_int(remminafile, "enableaudio", FALSE),
 		"enable-smartcard", remmina_plugin_service->file_get_int(remminafile, "sharesmartcard", FALSE),
 		"shared-dir", remmina_plugin_service->file_get_string(remminafile, "sharefolder"),
+		"proxy", remmina_plugin_service->file_get_string(remminafile, "proxy"),
 		NULL);
 
 	gpdata->gtk_session = spice_gtk_session_get(gpdata->session);
@@ -136,6 +138,14 @@ static void remmina_plugin_spice_init(RemminaProtocolWidget *gp)
 		"auto-clipboard",
 		!remmina_plugin_service->file_get_int(remminafile, "disableclipboard", FALSE),
 		NULL);
+
+	const gchar *filterstr = remmina_plugin_service->file_get_string(remminafile, "usbredir");
+	if (filterstr) {
+		gpdata->usbmanager = spice_usb_device_manager_get(gpdata->session, NULL);
+		if (gpdata->usbmanager != NULL) {
+			g_object_set(gpdata->usbmanager, "redirect-on-connect", filterstr, NULL);
+		}
+	}
 }
 
 static gboolean remmina_plugin_spice_open_connection(RemminaProtocolWidget *gp)
@@ -397,7 +407,6 @@ static void remmina_plugin_spice_main_channel_event_cb(SpiceChannel *channel, Sp
 			remmina_plugin_spice_open_connection(gp);
 		}else{
 			/* Connection is cancelled by the user by clicking cancel on auth panel, close it without showing errors */
-			// remmina_plugin_service->protocol_plugin_set_error(gp, _("Invalid password."));
 			remmina_plugin_spice_close_connection(gp);
 		}
 		break;
@@ -681,6 +690,8 @@ static const RemminaProtocolSetting remmina_plugin_spice_basic_settings[] =
 	{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK,		"usetls",		N_("Use TLS encryption"),	FALSE,	NULL, NULL, NULL, NULL },
 	{ REMMINA_PROTOCOL_SETTING_TYPE_FILE,		"cacert",		N_("Server CA certificate"),	FALSE,	NULL, NULL, NULL, NULL },
 	{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT,		"sharefolder",		N_("Share folder"),		FALSE,	NULL, NULL, NULL, NULL },
+    { REMMINA_PROTOCOL_SETTING_TYPE_TEXT,       "proxy",                N_("Proxy"),                 FALSE,  NULL, NULL, NULL, NULL },
+	{ REMMINA_PROTOCOL_SETTING_TYPE_TEXT,		"usbredir",		N_("USB device redirection"),	FALSE,  NULL, NULL, NULL, NULL },
 	{ REMMINA_PROTOCOL_SETTING_TYPE_END,		NULL,			NULL,				FALSE,	NULL, NULL, NULL, NULL }
 };
 
@@ -750,6 +761,22 @@ static RemminaProtocolPlugin remmina_plugin_spice =
 	NULL                                                                    // RCW unmap event
 };
 
+/* File plugin definition and features */
+static RemminaFilePlugin remmina_spicef =
+{
+	REMMINA_PLUGIN_TYPE_FILE,                       // Type
+	"SPICEF",                                       // Name
+	N_("SPICE vv file"),         					// Description
+	GETTEXT_PACKAGE,                                // Translation domain
+	VERSION,         					            // Version number
+	remmina_spice_file_import_test,                   // Test import function
+	remmina_spice_file_import,                        // Import function
+	remmina_spice_file_export_test,                   // Test export function
+	remmina_spice_file_export,                        // Export function
+	".vv",                        // Export extension
+	NULL
+};
+
 void remmina_plugin_spice_remove_list_option(gpointer *option_list, const gchar *option_to_remove) {
 	gpointer *src, *dst;
 
@@ -831,6 +858,12 @@ remmina_plugin_entry(RemminaPluginService *service)
 		return FALSE;
 	}
 
+	remmina_spicef.export_hints = _("Export connection in virt-viewer .vv file format");
+	remmina_spicef.export_ext = ".vv";
+
+	if (!service->register_plugin((RemminaPlugin *)&remmina_spicef))
+		return FALSE;
+
 	return TRUE;
 }
 
