@@ -1283,6 +1283,11 @@ static void remmina_set_file_chooser_filters(GtkFileChooser *chooser)
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), filter);
 	gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), filter);
 
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name(filter, _("Virt-Viewer Files"));
+	gtk_file_filter_add_pattern(filter, "*.vv");
+	gtk_file_chooser_add_filter(chooser, filter);
+
 	filter = gtk_file_filter_new();
 	gtk_file_filter_set_name(filter, _("All Files"));
 	gtk_file_filter_add_pattern(filter, "*");
@@ -1350,7 +1355,7 @@ void remmina_main_on_action_tools_export(GSimpleAction *action, GVariant *param,
 		gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(chooser), TRUE);
 		remmina_set_file_chooser_filters(GTK_FILE_CHOOSER(chooser));
 		gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(chooser), TRUE);
-		export_name = g_strdup_printf("%s.rdp", remminamain->priv->selected_name);
+		export_name = g_strdup_printf("%s%s", remminamain->priv->selected_name, plugin->export_ext);
 		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(chooser), export_name);
 		g_free(export_name);
 		g_signal_connect(chooser, "response", G_CALLBACK(on_export_save_response), remminafile);
@@ -1462,16 +1467,22 @@ static gboolean remmina_main_quickconnect(void)
 
 	remminafile = remmina_file_new();
 	server = g_strdup(gtk_entry_get_text(remminamain->entry_quick_connect_server));
-	if (g_hostname_to_ascii(server) == NULL)
+	if (g_hostname_to_ascii(server) == NULL) {
+		g_free(server), server = NULL;
 		return FALSE;
+	}
 	/* If server contain /, e.g. vnc://, it won't connect
 	 * We could search for an array of invalid characters, but
 	 * it's better to find a way to correctly parse and validate addresses
 	 */
-	if (g_strrstr(server, "/") != NULL)
+	if (g_strrstr(server, "/") != NULL) {
+		g_free(server), server = NULL;
 		return FALSE;
-	if (is_empty(server))
+	}
+	if (is_empty(server)){
+		g_free(server), server = NULL;
 		return FALSE;
+	}
 
 	/* check if server is an IP address and trim whitespace if so */
 	server_trimmed = g_strdup(server);
@@ -1878,4 +1889,4 @@ void remmina_main_show_warning_dialog(const gchar *message) {
         gtk_dialog_run(GTK_DIALOG(dialog));
         gtk_widget_destroy(dialog);
     }
-}
\ No newline at end of file
+}
