@@ -403,6 +403,16 @@ void remmina_pref_init(void)
 	else
 		remmina_pref.mp_left = FALSE;
 
+	if (g_key_file_has_key(gkeyfile, "remmina_pref", "start_fullscreen", NULL))
+		remmina_pref.start_fullscreen = g_key_file_get_boolean(gkeyfile, "remmina_pref", "start_fullscreen", NULL);
+	else
+		remmina_pref.start_fullscreen = FALSE;
+
+	if (g_key_file_has_key(gkeyfile, "remmina_pref", "start_dynres", NULL))
+		remmina_pref.start_dynres = g_key_file_get_boolean(gkeyfile, "remmina_pref", "start_dynres", NULL);
+	else
+		remmina_pref.start_dynres = FALSE;
+
 	if (g_key_file_has_key(gkeyfile, "remmina_pref", "hide_connection_toolbar", NULL))
 		remmina_pref.hide_connection_toolbar = g_key_file_get_boolean(gkeyfile, "remmina_pref",
 									      "hide_connection_toolbar", NULL);
@@ -929,6 +939,8 @@ gboolean remmina_pref_save(void)
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "always_show_tab", remmina_pref.always_show_tab);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "always_show_notes", remmina_pref.always_show_notes);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "mp_left", remmina_pref.mp_left);
+	g_key_file_set_boolean(gkeyfile, "remmina_pref", "start_fullscreen", remmina_pref.start_fullscreen);
+	g_key_file_set_boolean(gkeyfile, "remmina_pref", "start_dynres", remmina_pref.start_dynres);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "hide_connection_toolbar", remmina_pref.hide_connection_toolbar);
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "hide_searchbar", remmina_pref.hide_searchbar);
 	g_key_file_set_integer(gkeyfile, "remmina_pref", "default_action", remmina_pref.default_action);
